fn format_column_detail(col_type: &ColumnType) -> StringExpand description
Format a column type for the completion item detail field.
fn format_column_detail(col_type: &ColumnType) -> StringFormat a column type for the completion item detail field.