fn gather_columns<'a>(
ctx: &CompletionContext<'a>,
project_cache: Option<&ProjectCache>,
types_lock: &Types,
) -> Vec<CompletionCandidate<'a>>Expand description
Gather column candidates from dependency objects via the types cache.
fn gather_columns<'a>(
ctx: &CompletionContext<'a>,
project_cache: Option<&ProjectCache>,
types_lock: &Types,
) -> Vec<CompletionCandidate<'a>>Gather column candidates from dependency objects via the types cache.