fn gather_objects<'a>(
ctx: &CompletionContext<'a>,
project_cache: &ProjectCache,
types_lock: &Types,
) -> Vec<CompletionCandidate<'a>>Expand description
Gather object candidates from project objects and external dependencies.
fn gather_objects<'a>(
ctx: &CompletionContext<'a>,
project_cache: &ProjectCache,
types_lock: &Types,
) -> Vec<CompletionCandidate<'a>>Gather object candidates from project objects and external dependencies.